# Feathers

A simple Python package providing colormaps inspired by the colours of bird feathers.
Based on the [R package](https://github.com/shandiya/feathers).

### Demonstration
![Image demonstrating the Feathers colormaps](docs/assets/feathers.svg)

### Installation
Install the package from PyPI:
```bash
pip install cm_feathers
```

Or to develop it, clone this repository and install locally:
```bash
pip install -e .
```

### Usage
Simply import the package to make the colormaps available for use with Matplotlib:
```python
import feathers
```
-----------------------------
Available under the GNU General Public License v3.

Copyright (C) 2025 Harrison Nicholls
